@@ -46,7 +46,6 @@ from django.utils.translation import gettext_lazy as _
 # ######################################################################################################################
 from df_config.config.dynamic_settings import (
     AutocreateFile,
-    AutocreateFileContent,
     CallableSetting,
     Directory,
     ExpandIterable,
@@ -69,13 +68,13 @@ from df_config.guesses.databases import (
     databases,
     session_redis_dict,
     websocket_redis_dict,
+    websocket_redis_channels,
 )
 from df_config.guesses.log import log_configuration
 from df_config.guesses.misc import (
     DefaultListenAddress,
     allowed_hosts,
     excluded_django_commands,
-    generate_secret_key,
     project_name,
     required_packages,
     secure_hsts_seconds,
@@ -87,6 +86,10 @@ from df_config.guesses.misc import (
     url_parse_server_protocol,
     url_parse_ssl,
     use_x_forwarded_for,
+    AutocreateSecretKey,
+    get_asgi_application,
+    get_wsgi_application,
+    use_sentry,
 )
 from df_config.guesses.pipeline import (
     pipeline_compilers,
@@ -114,6 +117,7 @@ USE_DEBUG_TOOLBAR = is_package_present("debug_toolbar")
 USE_ALL_AUTH = is_package_present("allauth")
 USE_WEBSOCKETS = is_package_present("df_websockets")
 USE_SITE = is_package_present("df_site")
+USE_WHITENOISE = is_package_present("whitenoise")
 
 # ######################################################################################################################
 #
@@ -145,9 +149,7 @@ MEDIA_URL = "/media/"
 MIDDLEWARE = CallableSetting(middlewares)
 
 ROOT_URLCONF = "df_config.root_urls"
-SECRET_KEY = AutocreateFileContent(
-    "{LOCAL_PATH}/secret_key.txt", generate_secret_key, mode=0o600, length=60
-)
+SECRET_KEY = AutocreateSecretKey("{LOCAL_PATH}/secret_key.txt")
 SECURE_BROWSER_XSS_FILTER = True
 SECURE_CONTENT_TYPE_NOSNIFF = True
 SECURE_HSTS_INCLUDE_SUBDOMAINS = SettingReference("USE_SSL")
@@ -171,18 +173,20 @@ TEMPLATE_CONTEXT_PROCESSORS = [
     "django.template.context_processors.media",
     "django.template.context_processors.static",
     "django.template.context_processors.tz",
+    "django.template.context_processors.request",
     "django.contrib.messages.context_processors.messages",
     "df_config.context_processors.config",
     ExpandIterable("DF_TEMPLATE_CONTEXT_PROCESSORS"),
 ]
 TEST_RUNNER = "django.test.runner.DiscoverRunner"
+
 USE_I18N = True
 USE_L10N = True
 USE_THOUSAND_SEPARATOR = True
 USE_TZ = True
 USE_X_FORWARDED_HOST = True  # X-Forwarded-Host
 X_FRAME_OPTIONS = "SAMEORIGIN"
-WSGI_APPLICATION = "df_config.application.wsgi_application"
+WSGI_APPLICATION = CallableSetting(get_wsgi_application)
 
 # django.contrib.auth
 AUTHENTICATION_BACKENDS = CallableSetting(authentication_backends)
@@ -191,6 +195,7 @@ LOGIN_REDIRECT_URL = "{URL_PREFIX}"
 # LOGOUT_REDIRECT_URL = '{URL_PREFIX}'
 
 # django.contrib.sessions
+SESSION_ENGINE = "django.contrib.sessions.backends.db"
 if USE_REDIS_SESSIONS:
     SESSION_ENGINE = "redis_sessions.session"
 SESSION_COOKIE_SECURE = SettingReference("USE_SSL")
@@ -240,6 +245,7 @@ DF_CHECKED_REQUIREMENTS = CallableSetting(required_packages)
 
 # df_websockets
 WEBSOCKET_URL = "/ws/"  # set to None if you do not use websockets
+# by default, use the same Redis as django-channels
 WEBSOCKET_REDIS_CONNECTION = CallableSetting(websocket_redis_dict)
 WEBSOCKET_SIGNAL_DECODER = "json.JSONDecoder"
 WEBSOCKET_TOPIC_SERIALIZER = "df_websockets.topics.serialize_topic"
@@ -252,29 +258,12 @@ WINDOW_INFO_MIDDLEWARES = [
     "df_websockets.ws_middleware.Djangoi18nMiddleware",
     "df_websockets.ws_middleware.BrowserMiddleware",
 ]
-if USE_WEBSOCKETS:
-    ASGI_APPLICATION = "df_websockets.routing.application"
-else:
-    ASGI_APPLICATION = "df_config.application.asgi_application"
+ASGI_APPLICATION = CallableSetting(get_asgi_application)
 
 # django-channels
-CHANNEL_LAYERS = {
-    "default": {
-        "BACKEND": "channels_redis.core.RedisChannelLayer",
-        "CONFIG": {
-            "hosts": [
-                {
-                    "address": (
-                        "{WEBSOCKET_REDIS_HOST}",
-                        SettingReference("WEBSOCKET_REDIS_PORT"),
-                    ),
-                    "password": SettingReference("WEBSOCKET_REDIS_PASSWORD"),
-                    "db": SettingReference("WEBSOCKET_REDIS_DB"),
-                }
-            ]
-        },
-    }
-}
+# noinspection PyUnresolvedReferences
+CHANNEL_REDIS = CallableSetting(websocket_redis_channels)
+CHANNEL_LAYERS = {"default": SettingReference("CHANNEL_REDIS")}
 
 # django-pipeline
 PIPELINE = {
@@ -416,9 +405,6 @@ SESSION_REDIS = CallableSetting(session_redis_dict)
 USE_DJANGO_JQUERY = True
 JQUERY_URL = False
 
-# raven
-RAVEN_CONFIG = {"dsn": "{RAVEN_DSN}", "release": "{DF_PROJECT_VERSION}"}
-
 # ######################################################################################################################
 #
 # settings that should be customized for each project
@@ -438,7 +424,7 @@ DF_JS_CATALOG_VIEWS = ["django.contrib.admin"]
 DF_INSTALLED_APPS = ["{DF_MODULE_NAME}"]  # your django app!
 DF_MIDDLEWARE = []
 DF_TEMPLATE_CONTEXT_PROCESSORS = []
-DF_PIP_NAME = "{DF_MODULE_NAME}"  # anything such that "pip install {DF_PIP_NAME}" installs your project
+DF_PIP_NAME = "{DF_MODULE_NAME}"  # anything such that "python -m pip install {DF_PIP_NAME}" installs your project
 # only used in docs
 DF_REMOTE_USER_HEADER = None  # HTTP_REMOTE_USER
 DF_DEFAULT_GROUPS = [_("Users")]
@@ -536,14 +522,14 @@ SESSION_REDIS_PROTOCOL = "redis"
 SESSION_REDIS_HOST = "localhost"  # aliased in settings.ini as "[session]host"
 SESSION_REDIS_PORT = 6379  # aliased in settings.ini as "[session]port"
 SESSION_REDIS_DB = 1  # aliased in settings.ini as "[session]db"
-SESSION_REDIS_PASSWORD = ""  # aliased in settings.ini as "[session]password"
+SESSION_REDIS_PASSWORD = None  # aliased in settings.ini as "[session]password"
 
 # django_redis (cache)
 CACHE_PROTOCOL = "redis"
 CACHE_HOST = "localhost"  # aliased in settings.ini as "[cache]host"
 CACHE_PORT = 6379  # aliased in settings.ini as "[cache]port"
 CACHE_DB = 2  # aliased in settings.ini as "[cache]db"
-CACHE_PASSWORD = ""  # aliased in settings.ini as "[cache]password"
+CACHE_PASSWORD = None  # aliased in settings.ini as "[cache]password"
 
 # websockets
 WEBSOCKET_REDIS_PROTOCOL = "redis"
@@ -557,8 +543,8 @@ CELERY_PROTOCOL = "redis"
 CELERY_HOST = "localhost"  # aliased in settings.ini as "[celery]host"
 CELERY_PORT = 6379  # aliased in settings.ini as "[celery]port"
 CELERY_DB = 4  # aliased in settings.ini as "[celery]db"
-CELERY_PASSWORD = ""  # aliased in settings.ini as "[celery]password"
+CELERY_PASSWORD = None  # aliased in settings.ini as "[celery]password"
 CELERY_PROCESSES = 4
 
-# raven
-RAVEN_DSN = None
+# sentry.io
+USE_SENTRY = CallableSetting(use_sentry)
